@@ -23,7 +23,7 @@
 https://nbsphinx.readthedocs.io/
 
 """
-__version__ = '0.8.8'
+__version__ = '0.8.9'
 
 import collections.abc
 import copy
@@ -162,9 +162,12 @@ RST_TEMPLATE = """
 {{ output.data[datatype] | escape_latex | ansi2latex | indent | indent }}
         \\end{sphinxVerbatim}
 
+{# NB: The "raw" directive doesn't work with empty content #}
+{%- if output.data[datatype].strip() %}
     .. raw:: text
 
 {{ output.data[datatype] | indent | indent }}
+{%- endif %}
 
 {%- elif datatype in ['image/svg+xml', 'image/png', 'image/jpeg', 'application/pdf'] %}
 
@@ -360,7 +363,7 @@ LATEX_PREAMBLE = r"""
     \setbox\nbsphinxbox\vtop{{#1\par}}
     % reserve some space at bottom of page, else start new page
     \needspace{\dimexpr2.5\baselineskip+\ht\nbsphinxbox+\dp\nbsphinxbox}
-    % mimick vertical spacing from \section command
+    % mimic vertical spacing from \section command
       \addpenalty\@secpenalty
       \@tempskipa 3.5ex \@plus 1ex \@minus .2ex\relax
       \addvspace\@tempskipa
@@ -653,6 +656,7 @@ div.nboutput.container div.output_area > div[class^='highlight']{
 }
 
 /* Some additional styling taken form the Jupyter notebook CSS */
+.jp-RenderedHTMLCommon table,
 div.rendered_html table {
   border: none;
   border-collapse: collapse;
@@ -661,10 +665,14 @@ div.rendered_html table {
   font-size: 12px;
   table-layout: fixed;
 }
+.jp-RenderedHTMLCommon thead,
 div.rendered_html thead {
   border-bottom: 1px solid black;
   vertical-align: bottom;
 }
+.jp-RenderedHTMLCommon tr,
+.jp-RenderedHTMLCommon th,
+.jp-RenderedHTMLCommon td,
 div.rendered_html tr,
 div.rendered_html th,
 div.rendered_html td {
@@ -676,12 +684,15 @@ div.rendered_html td {
   max-width: none;
   border: none;
 }
+.jp-RenderedHTMLCommon th,
 div.rendered_html th {
   font-weight: bold;
 }
+.jp-RenderedHTMLCommon tbody tr:nth-child(odd),
 div.rendered_html tbody tr:nth-child(odd) {
   background: #f5f5f5;
 }
+.jp-RenderedHTMLCommon tbody tr:hover,
 div.rendered_html tbody tr:hover {
   background: rgba(66, 165, 245, 0.2);
 }
@@ -1237,7 +1248,7 @@ class NbGallery(sphinx.directives.other.TocTree):
     """A thumbnail gallery for notebooks."""
 
     def run(self):
-        """Wrap GalleryToc arount toctree."""
+        """Wrap GalleryToc around toctree."""
         ret = super().run()
         try:
             toctree_wrapper = ret[-1]
